==> igniteui-angular-charts-16.1.0-beta.0.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.v = null;
        }
        d(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.ab9 != null;
                    }
                    break;
            }
        }
        r(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.e("ShowGridlines", 2, a.ab9 != null);
                    break;
            }
        }
        i(a, b) {
            let c = a;
            if (this.b(b, "ShowGridlines")) {
                if (c.ab9 == null) {
                    if (this.v != null) {
                        c.ab9 = this.v;
                    }
                    else {
                        c.ab9 = c.dataChart.xv;
                    }
                }
            }
            else {
                if (c.ab9 != null) {
                    this.v = c.ab9;
                    c.ab9 = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();

==> igniteui-angular-charts-16.1.2-beta.0.tgz: package/esm2015/lib/CategoryChartToolbarProvider.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { DomainChartToolbarProvider } from "./DomainChartToolbarProvider";
import { markType } from "igniteui-angular-core";
/**
 * @hidden
 */
export let CategoryChartToolbarProvider = /*@__PURE__*/ (() => {
    class CategoryChartToolbarProvider extends DomainChartToolbarProvider {
        constructor() {
            super(...arguments);
            this.v = null;
        }
        d(a, b) {
            let c = a;
            switch (b.name) {
                case "ShowGridlines":
                    {
                        let d = b;
                        d.isChecked = c.acd != null;
                    }
                    break;
            }
        }
        r(a, b, c, d) {
            let e = a;
            switch (b) {
                case "XAxisMajorStroke":
                    this.e("ShowGridlines", 2, a.acd != null);
                    break;
            }
        }
        i(a, b) {
            let c = a;
            if (this.b(b, "ShowGridlines")) {
                if (c.acd == null) {
                    if (this.v != null) {
                        c.acd = this.v;
                    }
                    else {
                        c.acd = c.dataChart.xv;
                    }
                }
            }
            else {
                if (c.acd != null) {
                    this.v = c.acd;
                    c.acd = null;
                }
            }
        }
    }
    CategoryChartToolbarProvider.$t = markType(CategoryChartToolbarProvider, 'CategoryChartToolbarProvider', DomainChartToolbarProvider.$);
    return CategoryChartToolbarProvider;
})();
